@@ -110,6 +110,9 @@ class MundiQ:
         # LineString and Point won't show up when plotted; buffer
         shape = shape.apply(lambda g: g.buffer(2) if isinstance(g, LineString) or isinstance(g, Point) else g)
 
+        # convert to WGS84
+        shape = shape.set_crs(crs=self.pcs).to_crs(epsg=4326)
+
         # check color
         if name in self.plot_legend.keys():
             color = self.plot_legend[name]
@@ -164,11 +167,11 @@ class Mundi:
         res_keys = None
         res_outs = dict()
         # progressbar optional
-        finiter = list(unique_iterator.itertuples())[:20]
+        finiter = list(unique_iterator.iterrows())
         if progressbar:
             finiter = tqdm(finiter, total=len(unique_iterator))
 
-        for window in finiter:
+        for idx, window in finiter:
             Q = MundiQ(window, self.mapdata)
             res = fn(Q)
 
